# GPMC Installation

## Requirement
- g++ 4.7 or later
- cmake and make
- GMP bignum package
- MPFR
- zlib

## Installation
```
$ ./build.sh r
```
The binary executable file *gpmc* is put under bin/.
